@@ -269,7 +269,7 @@ class TestClient(object):
     async def test_search(self, event_loop, client, channel, random_user):
         query = "supercalifragilisticexpialidocious"
         await channel.send_message(
-            {"text": "How many syllables are there in {}?".format(query)},
+            {"text": f"How many syllables are there in {query}?"},
             random_user["id"],
         )
         await channel.send_message(
@@ -300,7 +300,7 @@ class TestClient(object):
 
     @pytest.mark.asyncio
     async def test_create_blocklist(self, event_loop, client):
-        response = await client.create_blocklist(name="Foo", words=["fudge", "heck"])
+        await client.create_blocklist(name="Foo", words=["fudge", "heck"])
 
     @pytest.mark.asyncio
     async def test_list_blocklists(self, event_loop, client):
@@ -324,3 +324,9 @@ class TestClient(object):
     @pytest.mark.asyncio
     async def test_delete_blocklist(self, event_loop, client):
         await client.delete_blocklist("Foo")
+
+    @pytest.mark.asyncio
+    async def test_check_sqs(self, client):
+        response = await client.check_sqs("key", "secret", "https://foo.com/bar")
+        assert response["status"] == "error"
+        assert "invalid SQS url" in response["error"]
